@@ -25,6 +25,9 @@
 #include <bakery/Utilities/BusyCursor.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_Database_Preferences::Dialog_Database_Preferences(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   Base_DB(),
@@ -91,14 +94,14 @@ void Dialog_Database_Preferences::on_treeview_cell_edited_next_value(const Glib:
     const Glib::ustring table_name = row[m_columns.m_col_table];
     const Glib::ustring field_name = row[m_columns.m_col_field];
 
-    const Gnome::Gda::Value next_value = GlomConversions::parse_value(new_value);
+    const Gnome::Gda::Value next_value = Conversions::parse_value(new_value);
 
     const Glib::ustring sql_query = "UPDATE \"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME "\" SET "
         "\"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_NEXT_VALUE "\" = " + next_value.to_string() +
         " WHERE \"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME "\" = '" + table_name + "' AND "
                "\"" GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME "\" = '" + field_name +"'";
 
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute(sql_query, this);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(sql_query, this);
     if(!datamodel)
     {
       g_warning("Dialog_Database_Preferences::on_treeview_cell_edited_next_value(): UPDATE failed.");
@@ -141,14 +144,14 @@ void Dialog_Database_Preferences::load_from_document()
 
   NumericFormat numeric_format; //ignored
 
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute(sql_query, this);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(sql_query, this);
   guint count = datamodel->get_n_rows();
   for(guint i = 0; i < count; ++i)
   {
     Gtk::TreeModel::iterator iter = m_model_autoincrements->append();
     Gtk::TreeModel::Row row = *iter;
-    row[m_columns.m_col_table] = GlomConversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(0, i), numeric_format);
-    row[m_columns.m_col_field] = GlomConversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(1, i), numeric_format);
+    row[m_columns.m_col_table] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(0, i), numeric_format);
+    row[m_columns.m_col_field] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(1, i), numeric_format);
 
     //TODO: Careful of locale:
     row[m_columns.m_col_next_value] = atol(datamodel->get_value_at(2, i).to_string().c_str());
@@ -190,3 +193,5 @@ void Dialog_Database_Preferences::on_button_choose_image()
 {
    m_image->do_choose_image();
 }
+
+} //namespace Glom
