@@ -20,9 +20,13 @@
 
 #include "box_db_table_definition.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/glom_postgres.h>
 #include "../../../config.h"
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_DB_Table_Definition::Box_DB_Table_Definition()
 {
   init();
@@ -156,7 +160,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
   Glib::ustring name = m_AddDel.get_value(row, m_colName);
   if(!name.empty())
   {
-    bool bTest = Query_execute( "ALTER TABLE \"" + m_table_name + "\" ADD \"" + name + "\" NUMERIC", get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
+    bool bTest = query_execute( "ALTER TABLE \"" + m_table_name + "\" ADD \"" + name + "\" NUMERIC", get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
     if(bTest)
     {
       //Show the new field (fill in the other cells):
@@ -168,7 +172,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
       //This must match the SQL statement above:
       sharedptr<Field> field(new Field());
       field->set_name(name);
-      field->set_title( util_title_from_string(name) ); //Start with a title that might be useful.
+      field->set_title( Utils::title_from_string(name) ); //Start with a title that might be useful.
       field->set_glom_type(Field::TYPE_NUMERIC);
 
       Gnome::Gda::FieldAttributes field_info = field->get_field_info();
@@ -196,7 +200,7 @@ void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& r
     Glib::ustring name = m_AddDel.get_value_key(iter);
     if(!name.empty())
     {
-      Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" + name + "\"", get_app_window());
+      query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" + name + "\"", get_app_window());
 
       //Remove it from all layouts, reports, etc:
       get_document()->remove_field(m_table_name, name);
@@ -207,13 +211,73 @@ void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& r
   fill_from_database();
 }
 
+bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field_new)
+{
+  bool result = true; //Tells the caller whether to continue.
+
+  Gtk::Window* parent_window = get_app_window();
+
+  //Warn about a long slow recalculation, and offer the chance to cancel it:
+  if(field_new->get_has_calculation())
+  {
+    if(field_new->get_calculation() != field_old->get_calculation())
+    {
+      //TODO: Only show this when there are > 100 records?
+      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Recalculation Required")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
+      dialog.set_secondary_text(_("You have changed the calculation used by this field so Glom must recalculate the value in all records. If the table contains many records then this could take a long time."));
+      if(parent_window)
+        dialog.set_transient_for(*parent_window);
+
+      dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+      dialog.add_button(_("Recalculate"), Gtk::RESPONSE_OK);
+      result = (dialog.run() == Gtk::RESPONSE_OK);
+    }
+  }
+
+  //If we are changing a non-glom type:
+  //Refuse to edit field definitions that were not created by glom:
+  if(Field::get_glom_type_for_gda_type( field_old->get_field_info().get_gdatype() )  == Field::TYPE_INVALID)
+  {
+    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Invalid database structure")), true);
+    dialog.set_secondary_text(_("This database field was created or edited outside of Glom. It has a data type that is not supported by Glom. Your system administrator may be able to correct this."));
+    if(parent_window)
+       dialog.set_transient_for(*parent_window);
+
+    dialog.run();
+
+    result = false;
+  }
+  else
+  {
+    //Refuse to set a second primary key:
+    bool bcontinue = true;
+    if(field_new->get_primary_key() && !field_old->get_primary_key()) //Was the primary key column checked?
+    {
+      //Is there an existing primary key?
+      sharedptr<Field> existing_primary_key = get_field_primary_key_for_table(m_table_name);
+      if(existing_primary_key)
+      {
+        //Warn the user and refuse to make the change:
+        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Too many primary keys")), true);
+        dialog.set_secondary_text(_("You may not specify more than one field as the primary key."));
+        if(parent_window)
+          dialog.set_transient_for(*parent_window);
+        dialog.run();
+
+        result = false;
+      }
+    }
+  }
+
+  return result;
+}
+
 void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
 {
   //Get old field definition:
   Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
   if(pDoc)
   {
-    //Glom-specific stuff: //TODO_portiter
     const Glib::ustring strFieldNameBeingEdited = m_AddDel.get_value_key(row);
 
     sharedptr<const Field> constfield = pDoc->get_field(m_table_name, strFieldNameBeingEdited);
@@ -232,17 +296,19 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
       //Change it:
       if(*m_Field_BeingEdited != *fieldNew) //If it has really changed.
       {
-        //If we are changing a non-glom type:
-        //Refuse to edit field definitions that were not created by glom:
-        if(Field::get_glom_type_for_gda_type( m_Field_BeingEdited->get_field_info().get_gdatype() )  == Field::TYPE_INVALID)
+        const bool bcontinue = check_field_change(m_Field_BeingEdited, fieldNew);
+        if(bcontinue)
         {
-          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Invalid database structure")), true);
-          dialog.set_secondary_text(_("This database field was created or edited outside of Glom. It has a data type that is not supported by Glom. Your system administrator may be able to correct this."));
-          //TODO: dialog.set_transient_for(*get_application());
-          dialog.run();
+          sharedptr<Field> fieldNewWithModifications = change_definition(m_Field_BeingEdited, fieldNew);
+
+          //Update the row to show any extra changes (such as unique being set/unset whenever the primary key is set/unset) 
+          fill_field_row(row, fieldNewWithModifications);
         }
         else
-          change_definition(m_Field_BeingEdited, fieldNew);
+        {
+          //revert:
+          fill_field_row(row, m_Field_BeingEdited);
+        }
       }
     }
   }
@@ -333,38 +399,11 @@ void Box_DB_Table_Definition::on_Properties_apply()
 
   if(*m_Field_BeingEdited != *field_New)
   {
-    //If we are changing a non-glom type:
-    //Refuse to edit field definitions that were not created by glom:
-    if( Field::get_glom_type_for_gda_type(m_Field_BeingEdited->get_field_info().get_gdatype()) == Field::TYPE_INVALID )
+    const bool bcontinue = check_field_change(m_Field_BeingEdited, field_New);
+    if(bcontinue)
     {
-      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Invalid database structure")), true);
-         dialog.set_secondary_text(_("This database field was created or edited outside of Glom. It has a data type that is not supported by Glom. Your system administrator may be able to correct this."));
-      //TODO: dialog.set_transient_for(*get_app_window());
-      dialog.run();
-    }
-    else
-    {
-      //Warn about recalculation:
-      bool change_def = true;
-      if(field_New->get_has_calculation())
-      {
-        if(field_New->get_calculation() != m_Field_BeingEdited->get_calculation())
-        {
-          //TODO: Only show this when there are > 100 records?
-          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Recalculation Required")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
-          dialog.set_secondary_text(_("You have changed the calculation used by this field so Glom must recalculate the value in all records. If the table contains many records then this could take a long time."));
-          //dialog.set_transient_for(*get_app_window());
-          dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-          dialog.add_button(_("Recalculate"), Gtk::RESPONSE_OK);
-          change_def = (dialog.run() == Gtk::RESPONSE_OK);
-        }
-      }
-
-      if(change_def)
-      {
-        change_definition(m_Field_BeingEdited, field_New);
-        m_Field_BeingEdited = field_New;
-      }
+      change_definition(m_Field_BeingEdited, field_New);
+      m_Field_BeingEdited = field_New;
     }
 
     //Update the list:
@@ -374,14 +413,31 @@ void Box_DB_Table_Definition::on_Properties_apply()
   m_pDialog->hide();
 }
 
-void Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fieldOld, const sharedptr<const Field>& field)
+sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fieldOld, const sharedptr<const Field>& field)
 {
   Bakery::BusyCursor busy_cursor(get_app_window());
 
   //DB field defintion:
 
-  postgres_change_column(fieldOld, field);
+  sharedptr<Field> result;
 
+  try
+  {
+    result = postgres_change_column(fieldOld, field);
+  }
+  catch(const std::exception& ex) //In case the database reports an error.
+  {
+    handle_error(ex);
+
+    //Give up. Don't update the document. Hope that we can read the current field properties from the database.
+    fill_fields();
+    //fill_from_database(); //We should not change the database definition in a cell renderer signal handler.
+
+    //Select the same field again:
+    m_AddDel.select_item(field->get_name(), m_colName, false);
+
+    return glom_sharedptr_clone(field); 
+  }
 
    //MySQL does this all with ALTER_TABLE, with "CHANGE" followed by the same details used with "CREATE TABLE",
    //MySQL also makes it easier to change the type.
@@ -401,12 +457,12 @@ void Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fi
     {
       //Change it to the new Fields's value:
       sharedptr<Field> refField = *iterFind;
-      *refField = *field;
+      *refField = *result; //Remember, result is field with any necessary changes due to constraints.
     }
     else
     {
       //Add it, because it's not there already:
-      vecFields.push_back( glom_sharedptr_clone(field) );
+      vecFields.push_back( glom_sharedptr_clone(result) );
     }
 
     pDoc->set_table_fields(m_table_name, vecFields);
@@ -434,6 +490,8 @@ void Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fi
 
   //Select the same field again:
   m_AddDel.select_item(field->get_name(), m_colName, false);
+
+  return result;
 }
 
 void Box_DB_Table_Definition::fill_fields()
@@ -441,7 +499,7 @@ void Box_DB_Table_Definition::fill_fields()
   m_vecFields = get_fields_for_table(m_table_name);
 }
 
-void  Box_DB_Table_Definition::postgres_change_column(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field)
+sharedptr<Field> Box_DB_Table_Definition::postgres_change_column(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field)
 {
   const Gnome::Gda::FieldAttributes field_info = field->get_field_info();
   const Gnome::Gda::FieldAttributes field_info_old = field_old->get_field_info();
@@ -450,11 +508,12 @@ void  Box_DB_Table_Definition::postgres_change_column(const sharedptr<const Fiel
   if( field_info.get_gdatype() != field_info_old.get_gdatype() )
   {
     postgres_change_column_type(field_old, field); //This will also change everything else at the same time.
+    return glom_sharedptr_clone(field);
   }
   else
   {
     //Change other stuff, without changing the type:
-    postgres_change_column_extras(m_table_name, field_old, field);
+    return GlomPostgres::postgres_change_column_extras(m_table_name, field_old, field);
   }
 }
 
@@ -488,7 +547,7 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
 
         sharedptr<Field> fieldTemp = glom_sharedptr_clone(field);
         fieldTemp->set_name("glom_temp_column");
-        postgres_add_column(m_table_name, fieldTemp); //This might also involves several commands.
+        GlomPostgres::postgres_add_column(m_table_name, fieldTemp); //This might also involves several commands.
 
 
         bool conversion_failed = false;
@@ -572,17 +631,17 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
             }
           }
 
-          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "UPDATE \"" + m_table_name + "\" SET \"" + fieldTemp->get_name() + "\" = " + conversion_command, get_app_window());  //TODO: Not full type details.
+          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute( "UPDATE \"" + m_table_name + "\" SET \"" + fieldTemp->get_name() + "\" = " + conversion_command, get_app_window());  //TODO: Not full type details.
           if(!datamodel)
             conversion_failed = true;
         }
 
         if(!conversion_failed)
         {
-          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" +  field_old->get_name() + "\"", get_app_window());
+          Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute( "ALTER TABLE \"" + m_table_name + "\" DROP COLUMN \"" +  field_old->get_name() + "\"", get_app_window());
           if(datamodel)
           {
-            datamodel = Query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN \"" + fieldTemp->get_name() + "\" TO \"" + field->get_name() + "\"", get_app_window());
+            datamodel = query_execute( "ALTER TABLE \"" + m_table_name + "\" RENAME COLUMN \"" + fieldTemp->get_name() + "\" TO \"" + field->get_name() + "\"", get_app_window());
             if(datamodel)
             {
               const bool test = gda_connection->commit_transaction(transaction);
@@ -599,10 +658,11 @@ void  Box_DB_Table_Definition::postgres_change_column_type(const sharedptr<const
     }  /// If the datatype has changed:
 
     if(!new_column_created) //We don't need to change anything else if everything was alrady correctly set as a new column:
-      postgres_change_column_extras(m_table_name, field_old, field);
+      GlomPostgres::postgres_change_column_extras(m_table_name, field_old, field);
   }
 }
 
+} //namespace Glom
 
 
 
