@@ -21,10 +21,13 @@
 #ifndef GLOM_MODE_DATA_LAYOUT_WIDGET_BASE_H
 #define GLOM_MODE_DATA_LAYOUT_WIDGET_BASE_H
 
-#include "../data_structure/layout/layoutitem.h"
+#include <glom/libglom/data_structure/layout/layoutitem.h>
 #include <gtkmm.h>
 #include "../mode_data/treestore_layout.h" //Forthe enum.
 
+namespace Glom
+{
+
 class App_Glom;
 
 class LayoutWidgetBase : virtual public sigc::trackable
@@ -94,4 +97,6 @@ protected:
 
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DATA_LAYOUT_WIDGET_BASE_H
